@@ -1,15 +1,6 @@
 # +
 import pandas as pd
-import logging
-
-# configure logger
-logging_format = ('%(asctime)s | %(levelname)s     '
-                  '| pangres     | %(module)s:%(funcName)s:%(lineno)s '
-                  '- %(message)s')
-logging.basicConfig(format=logging_format, datefmt='%Y-%m-%d %H:%M:%S')
-logger = logging.getLogger('pangres')
-logger.setLevel(logging.INFO)
-
+from pangres.logger import log
 
 # -
 
@@ -104,7 +95,7 @@ def fix_psycopg2_bad_cols(df:pd.DataFrame, replacements={'%':'', '(':'', ')':''}
     for i, j in zip(before, after):
         if (isinstance(i, str) and isinstance(j, str)
             and i!=j):
-            logger.info(f'Renamed column/index "{i}" to "{j}s"')
+            log(f'Renamed column/index "{i}" to "{j}s"')
     return new_df
 
 
